Trait frame::derive::TypeInfo

pub trait TypeInfo {
    type Identity: 'static + ?Sized;

    // Required method
    fn type_info() -> Type<MetaForm>;
}
Implementors return their meta type information.

Required Associated Types

type Identity: 'static + ?Sized

The type identifying for which type info is provided.

Note

This is used to uniquely identify a type via core::any::TypeId::of. In most cases it will just be Self, but can be used to unify different types which have the same encoded representation e.g. reference types Box<T>, &T and &mut T.

Required Methods

fn type_info() -> Type<MetaForm>

Returns the static type identifier for Self.

Implementations on Foreign Types



impl<T, H> TypeInfo for Bounded<T, H>where H: Hash + TypeInfo + 'static, <H as Hash>::Output: TypeInfo + 'static, PhantomData<T>: TypeInfo + 'static, T: TypeInfo + 'static,



type Identity = Bounded<T, H>



fn type_info() -> Type<MetaForm>



impl TypeInfo for Pays



type Identity = Pays



fn type_info() -> Type<MetaForm>



impl TypeInfo for PostDispatchInfo



type Identity = PostDispatchInfo



fn type_info() -> Type<MetaForm>



impl TypeInfo for DispatchClass



type Identity = DispatchClass



fn type_info() -> Type<MetaForm>



impl TypeInfo for DispatchInfo



type Identity = DispatchInfo



fn type_info() -> Type<MetaForm>



impl TypeInfo for PalletId



type Identity = PalletId



fn type_info() -> Type<MetaForm>



impl TypeInfo for Never



type Identity = Never



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for PerDispatchClass<T>where T: TypeInfo + 'static,



type Identity = PerDispatchClass<T>



fn type_info() -> Type<MetaForm>



impl TypeInfo for u64



type Identity = u64



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for Cow<'static, T>where T: ToOwned + TypeInfo + 'static + ?Sized,



type Identity = Cow<'static, T>



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J> TypeInfo for (A, B, C, D, E, F, G, H, I, J)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static, T: TypeInfo + 'static,



impl<T, E> TypeInfo for Result<T, E>where T: TypeInfo + 'static, E: TypeInfo + 'static,



type Identity = Result<T, E>



fn type_info() -> Type<MetaForm>



impl<Idx> TypeInfo for RangeInclusive<Idx>where Idx: TypeInfo + 'static + PartialOrd<Idx> + Debug,



type Identity = RangeInclusive<Idx>



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for Compact<T>where T: TypeInfo + 'static,



type Identity = Compact<T>



fn type_info() -> Type<MetaForm>



impl TypeInfo for Lsb0



type Identity = Lsb0



fn type_info() -> Type<MetaForm>



impl TypeInfo for char



type Identity = char



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroI16



type Identity = NonZeroI16



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I> TypeInfo for (A, B, C, D, E, F, G, H, I)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static,



impl TypeInfo for u8



type Identity = u8



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for Vec<T, Global>where T: TypeInfo + 'static,



type Identity = [T]



fn type_info() -> Type<MetaForm>



impl TypeInfo for u128



type Identity = u128



fn type_info() -> Type<MetaForm>



impl TypeInfo for Msb0



type Identity = Msb0



fn type_info() -> Type<MetaForm>



impl TypeInfo for i8



type Identity = i8



fn type_info() -> Type<MetaForm>



impl TypeInfo for bool



type Identity = bool



fn type_info() -> Type<MetaForm>



impl TypeInfo for u32



type Identity = u32



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for &Twhere T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type<MetaForm>



impl TypeInfo for ()



type Identity = ()



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static,



impl<T> TypeInfo for Option<T>where T: TypeInfo + 'static,



type Identity = Option<T>



fn type_info() -> Type<MetaForm>



impl TypeInfo for u16



type Identity = u16



fn type_info() -> Type<MetaForm>



impl<A, B, C, D> TypeInfo for (A, B, C, D)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static,



type Identity = (A, B, C, D)



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroU128



type Identity = NonZeroU128



fn type_info() -> Type<MetaForm>



impl<K, V> TypeInfo for BTreeMap<K, V, Global>where K: TypeInfo + 'static, V: TypeInfo + 'static,



type Identity = BTreeMap<K, V, Global>



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static,



impl<T> TypeInfo for [T]where T: TypeInfo + 'static,



type Identity = [T]



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroI128



type Identity = NonZeroI128



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E> TypeInfo for (A, B, C, D, E)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static,



type Identity = (A, B, C, D, E)



fn type_info() -> Type<MetaForm>



impl<A, B> TypeInfo for (A, B)where A: TypeInfo + 'static, B: TypeInfo + 'static,



type Identity = (A, B)



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroU32



type Identity = NonZeroU32



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroI8



type Identity = NonZeroI8



fn type_info() -> Type<MetaForm>



impl TypeInfo for i64



type Identity = i64



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for Rc<T, Global>where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type<MetaForm>



impl<T, const N: usize> TypeInfo for [T; N]where T: TypeInfo + 'static,



type Identity = [T; N]



fn type_info() -> Type<MetaForm>



impl TypeInfo for i128



type Identity = i128



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G> TypeInfo for (A, B, C, D, E, F, G)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static,



type Identity = (A, B, C, D, E, F, G)



fn type_info() -> Type<MetaForm>



impl<Idx> TypeInfo for Range<Idx>where Idx: TypeInfo + 'static + PartialOrd<Idx> + Debug,



type Identity = Range<Idx>



fn type_info() -> Type<MetaForm>



impl TypeInfo for i32



type Identity = i32



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for Arc<T, Global>where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H> TypeInfo for (A, B, C, D, E, F, G, H)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static,



type Identity = (A, B, C, D, E, F, G, H)



fn type_info() -> Type<MetaForm>



impl TypeInfo for String



type Identity = str



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static,



impl<T, O> TypeInfo for BitVec<T, O>where T: BitStore + TypeInfo + 'static, O: BitOrder + TypeInfo + 'static,



type Identity = BitVec<T, O>



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for Box<T, Global>where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type<MetaForm>



impl TypeInfo for Duration



type Identity = Duration



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static,



impl TypeInfo for NonZeroU16



type Identity = NonZeroU16



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F> TypeInfo for (A, B, C, D, E, F)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static,



type Identity = (A, B, C, D, E, F)



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroI64



type Identity = NonZeroI64



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for BTreeSet<T, Global>where T: TypeInfo + 'static,



type Identity = BTreeSet<T, Global>



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroU8



type Identity = NonZeroU8



fn type_info() -> Type<MetaForm>



impl TypeInfo for i16



type Identity = i16



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static,



impl TypeInfo for NonZeroI32



type Identity = NonZeroI32



fn type_info() -> Type<MetaForm>



impl<A> TypeInfo for (A,)where A: TypeInfo + 'static,



type Identity = (A,)



fn type_info() -> Type<MetaForm>



impl TypeInfo for NonZeroU64



type Identity = NonZeroU64



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static,



impl<T> TypeInfo for VecDeque<T, Global>where T: TypeInfo + 'static,



type Identity = [T]



fn type_info() -> Type<MetaForm>



impl<A, B, C, D, E, F, G, H, I, J, K, L, M> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static,



impl TypeInfo for str



type Identity = str



fn type_info() -> Type<MetaForm>



impl<T> TypeInfo for &mut Twhere T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type<MetaForm>



impl<A, B, C> TypeInfo for (A, B, C)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static,



type Identity = (A, B, C)



fn type_info() -> Type<MetaForm>



impl TypeInfo for AccountId32



type Identity = AccountId32



fn type_info() -> Type<MetaForm>



impl TypeInfo for VrfSignature



type Identity = VrfSignature



fn type_info() -> Type<MetaForm>



impl<const LEFT_PLUS_RIGHT_LEN: usize> TypeInfo for Public<LEFT_PLUS_RIGHT_LEN>



type Identity = Public<LEFT_PLUS_RIGHT_LEN>



fn type_info() -> Type<MetaForm>



impl<const LEFT_PLUS_RIGHT_LEN: usize> TypeInfo for Signature<LEFT_PLUS_RIGHT_LEN>



type Identity = Signature<LEFT_PLUS_RIGHT_LEN>



fn type_info() -> Type<MetaForm>



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type<MetaForm>



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type<MetaForm>



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type<MetaForm>



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type<MetaForm>



impl TypeInfo for Void



type Identity = Void



fn type_info() -> Type<MetaForm>



impl TypeInfo for OpaqueMultiaddr



type Identity = OpaqueMultiaddr



fn type_info() -> Type<MetaForm>



impl TypeInfo for OpaquePeerId



type Identity = OpaquePeerId



fn type_info() -> Type<MetaForm>



impl TypeInfo for VrfProof



type Identity = [u8; 64]



fn type_info() -> Type<MetaForm>



impl TypeInfo for OpaqueNetworkState



type Identity = OpaqueNetworkState



fn type_info() -> Type<MetaForm>



impl TypeInfo for VrfOutput



type Identity = [u8; 32]



fn type_info() -> Type<MetaForm>



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type<MetaForm>



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type<MetaForm>



impl TypeInfo for H768



type Identity = H768



fn type_info() -> Type<MetaForm>



impl TypeInfo for U128



type Identity = U128



fn type_info() -> Type<MetaForm>



impl TypeInfo for H128



type Identity = H128



fn type_info() -> Type<MetaForm>



impl TypeInfo for H384



type Identity = H384



fn type_info() -> Type<MetaForm>



impl<'a, T, S> TypeInfo for BoundedSlice<'a, T, S>where 'a: 'static, &'a [T]: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: TypeInfo + 'static,



type Identity = BoundedSlice<'a, T, S>



fn type_info() -> Type<MetaForm>



impl<T, S> TypeInfo for BoundedVec<T, S>where Vec<T, Global>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: 'static,



type Identity = BoundedVec<T, S>



fn type_info() -> Type<MetaForm>



impl<T, S> TypeInfo for WeakBoundedVec<T, S>where Vec<T, Global>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: 'static,



type Identity = WeakBoundedVec<T, S>



fn type_info() -> Type<MetaForm>



impl<T, S> TypeInfo for BoundedBTreeSet<T, S>where BTreeSet<T, Global>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: 'static,



type Identity = BoundedBTreeSet<T, S>



fn type_info() -> Type<MetaForm>



impl<K, V, S> TypeInfo for BoundedBTreeMap<K, V, S>where BTreeMap<K, V, Global>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, K: TypeInfo + 'static, V: TypeInfo + 'static, S: 'static,



type Identity = BoundedBTreeMap<K, V, S>



fn type_info() -> Type<MetaForm>



impl TypeInfo for MultiSigner



type Identity = MultiSigner



fn type_info() -> Type<MetaForm>



impl TypeInfo for TransactionValidityError



type Identity = TransactionValidityError



fn type_info() -> Type<MetaForm>



impl TypeInfo for OpaqueExtrinsic



type Identity = OpaqueExtrinsic



fn type_info() -> Type<MetaForm>



impl TypeInfo for Digest



type Identity = Digest



fn type_info() -> Type<MetaForm>



impl TypeInfo for ModuleError



type Identity = ModuleError



fn type_info() -> Type<MetaForm>



impl<Header, Extrinsic> TypeInfo for Block<Header, Extrinsic>where Header: TypeInfo + 'static, Vec<Extrinsic, Global>: TypeInfo + 'static, Extrinsic: TypeInfo + 'static,



type Identity = Block<Header, Extrinsic>



fn type_info() -> Type<MetaForm>



impl TypeInfo for DispatchError



type Identity = DispatchError



fn type_info() -> Type<MetaForm>



impl TypeInfo for ValidTransaction



type Identity = ValidTransaction



fn type_info() -> Type<MetaForm>



impl TypeInfo for TransactionSource



type Identity = TransactionSource



fn type_info() -> Type<MetaForm>



impl<AccountId, AccountIndex> TypeInfo for MultiAddress<AccountId, AccountIndex>where AccountId: TypeInfo + 'static, AccountIndex: HasCompact + TypeInfo + 'static,



type Identity = MultiAddress<AccountId, AccountIndex>



fn type_info() -> Type<MetaForm>



impl<'a> TypeInfo for PiecewiseLinear<'a>where 'a: 'static,



type Identity = PiecewiseLinear<'a>



fn type_info() -> Type<MetaForm>



impl TypeInfo for UnknownTransaction



type Identity = UnknownTransaction



fn type_info() -> Type<MetaForm>



impl TypeInfo for ModuleError



type Identity = ModuleError



fn type_info() -> Type<MetaForm>



impl TypeInfo for MultiSignature



type Identity = MultiSignature



fn type_info() -> Type<MetaForm>



impl<Number, Hash> TypeInfo for Header<Number, Hash>where Number: Copy + Into<U256> + TryFrom<U256> + HasCompact + TypeInfo + 'static, Hash: Hash + 'static, <Hash as Hash>::Output: TypeInfo + 'static,



type Identity = Header<Number, Hash>



fn type_info() -> Type<MetaForm>



impl TypeInfo for InvalidTransaction



type Identity = InvalidTransaction



fn type_info() -> Type<MetaForm>



impl TypeInfo for Era



type Identity = Era



fn type_info() -> Type<MetaForm>



impl<Xt> TypeInfo for Block<Xt>where Vec<Xt, Global>: TypeInfo + 'static, Xt: TypeInfo + 'static,



type Identity = Block<Xt>



fn type_info() -> Type<MetaForm>



impl TypeInfo for DispatchError



type Identity = DispatchError



fn type_info() -> Type<MetaForm>



impl TypeInfo for UintAuthorityId



type Identity = UintAuthorityId



fn type_info() -> Type<MetaForm>



impl<Info> TypeInfo for DispatchErrorWithPostInfo<Info>where Info: Eq + PartialEq<Info> + Clone + Copy + Encode + Decode + Printable + TypeInfo + 'static,



type Identity = DispatchErrorWithPostInfo<Info>



fn type_info() -> Type<MetaForm>



impl TypeInfo for TokenError



type Identity = TokenError



fn type_info() -> Type<MetaForm>



impl TypeInfo for TestSignature



type Identity = TestSignature



fn type_info() -> Type<MetaForm>



impl<Call, Extra> TypeInfo for TestXt<Call, Extra>where Option<(u64, Extra)>: TypeInfo + 'static, Call: TypeInfo + 'static, Extra: TypeInfo + 'static,



type Identity = TestXt<Call, Extra>



fn type_info() -> Type<MetaForm>



impl TypeInfo for DigestItem



type Identity = DigestItem



fn type_info() -> Type<MetaForm>



impl TypeInfo for TransactionalError



type Identity = TransactionalError



fn type_info() -> Type<MetaForm>



impl TypeInfo for AnySignature



type Identity = AnySignature



fn type_info() -> Type<MetaForm>



impl<Address, Call, Signature, Extra> TypeInfo for UncheckedExtrinsic<Address, Call, Signature, Extra>where Address: StaticTypeInfo, Call: StaticTypeInfo, Signature: StaticTypeInfo, Extra: SignedExtension + StaticTypeInfo,

Manual TypeInfo implementation because of custom encoding. The data is a valid encoded Vec<u8>, but requires some logic to extract the signature and payload.

See [UncheckedExtrinsic::encode] and [UncheckedExtrinsic::decode].



type Identity = UncheckedExtrinsic<Address, Call, Signature, Extra>



fn type_info() -> Type<MetaForm>



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type<MetaForm>



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type<MetaForm>



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type<MetaForm>



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type<MetaForm>



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type<MetaForm>



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type<MetaForm>



impl TypeInfo for CompactProof



type Identity = CompactProof



fn type_info() -> Type<MetaForm>



impl TypeInfo for Weight



type Identity = Weight



fn type_info() -> Type<MetaForm>



impl TypeInfo for OldWeight



type Identity = OldWeight



fn type_info() -> Type<MetaForm>



impl TypeInfo for RuntimeDbWeight



type Identity = RuntimeDbWeight



fn type_info() -> Type<MetaForm>



impl<Balance> TypeInfo for WeightToFeeCoefficient<Balance>where Balance: TypeInfo + 'static,



type Identity = WeightToFeeCoefficient<Balance>



fn type_info() -> Type<MetaForm>



impl<AccountId> TypeInfo for StakerStatus<AccountId>where Vec<AccountId, Global>: TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = StakerStatus<AccountId>



fn type_info() -> Type<MetaForm>



impl<Reporter, Offender> TypeInfo for OffenceDetails<Reporter, Offender>where Offender: TypeInfo + 'static, Vec<Reporter, Global>: TypeInfo + 'static, Reporter: TypeInfo + 'static,



type Identity = OffenceDetails<Reporter, Offender>



fn type_info() -> Type<MetaForm>



impl<AccountId, Balance> TypeInfo for ExposurePage<AccountId, Balance>where Balance: HasCompact + TypeInfo + 'static, Vec<IndividualExposure<AccountId, Balance>, Global>: TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = ExposurePage<AccountId, Balance>



fn type_info() -> Type<MetaForm>



impl<Balance> TypeInfo for PagedExposureMetadata<Balance>where Balance: HasCompact + MaxEncodedLen + TypeInfo + 'static,



type Identity = PagedExposureMetadata<Balance>



fn type_info() -> Type<MetaForm>



impl<AccountId, Balance> TypeInfo for Exposure<AccountId, Balance>where Balance: HasCompact + TypeInfo + 'static, Vec<IndividualExposure<AccountId, Balance>, Global>: TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = Exposure<AccountId, Balance>



fn type_info() -> Type<MetaForm>



impl TypeInfo for DisableStrategy



type Identity = DisableStrategy



fn type_info() -> Type<MetaForm>



impl<AccountId, Balance> TypeInfo for IndividualExposure<AccountId, Balance>where Balance: HasCompact + TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = IndividualExposure<AccountId, Balance>



fn type_info() -> Type<MetaForm>



impl<Header, Id> TypeInfo for EquivocationProof<Header, Id>where Id: TypeInfo + 'static, Header: TypeInfo + 'static,



type Identity = EquivocationProof<Header, Id>



fn type_info() -> Type<MetaForm>



impl<H, N> TypeInfo for Message<H, N>where Prevote<H, N>: TypeInfo + 'static, Precommit<H, N>: TypeInfo + 'static, PrimaryPropose<H, N>: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = Message<H, N>



fn type_info() -> Type<MetaForm>



impl<Id, V, S> TypeInfo for Equivocation<Id, V, S>where Id: TypeInfo + 'static, (V, S): TypeInfo + 'static, V: TypeInfo + 'static, S: TypeInfo + 'static,



type Identity = Equivocation<Id, V, S>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for CatchUp<H, N, S, Id>where Vec<SignedPrevote<H, N, S, Id>, Global>: TypeInfo + 'static, Vec<SignedPrecommit<H, N, S, Id>, Global>: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static,



type Identity = CatchUp<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for CompactCommit<H, N, S, Id>where H: TypeInfo + 'static, N: TypeInfo + 'static, Vec<Precommit<H, N>, Global>: TypeInfo + 'static, Vec<(S, Id), Global>: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static,



type Identity = CompactCommit<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for SignedPrevote<H, N, S, Id>where Prevote<H, N>: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = SignedPrevote<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N> TypeInfo for Precommit<H, N>where H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = Precommit<H, N>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for SignedPrecommit<H, N, S, Id>where Precommit<H, N>: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = SignedPrecommit<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for Commit<H, N, S, Id>where H: TypeInfo + 'static, N: TypeInfo + 'static, Vec<SignedPrecommit<H, N, S, Id>, Global>: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static,



type Identity = Commit<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for SignedMessage<H, N, S, Id>where Message<H, N>: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = SignedMessage<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N, S, Id> TypeInfo for HistoricalVotes<H, N, S, Id>where Vec<SignedMessage<H, N, S, Id>, Global>: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static, S: TypeInfo + 'static, Id: TypeInfo + 'static,



type Identity = HistoricalVotes<H, N, S, Id>



fn type_info() -> Type<MetaForm>



impl<H, N> TypeInfo for PrimaryPropose<H, N>where H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = PrimaryPropose<H, N>



fn type_info() -> Type<MetaForm>



impl<H, N> TypeInfo for State<H, N>where Option<(H, N)>: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = State<H, N>



fn type_info() -> Type<MetaForm>



impl<H, N> TypeInfo for Prevote<H, N>where H: TypeInfo + 'static, N: TypeInfo + 'static,



type Identity = Prevote<H, N>



fn type_info() -> Type<MetaForm>



impl TypeInfo for MembershipProof



type Identity = MembershipProof



fn type_info() -> Type<MetaForm>

Implementors



impl TypeInfo for ArithmeticError



impl TypeInfo for Phase



impl TypeInfo for RuntimeString



impl TypeInfo for BalanceStatus



impl TypeInfo for ProcessMessageError



impl TypeInfo for LookupError



impl TypeInfo for PaymentStatus



impl TypeInfo for FixedI64



impl TypeInfo for FixedI128



impl TypeInfo for FixedU64



impl TypeInfo for FixedU128



impl TypeInfo for PerU16



impl TypeInfo for Perbill



impl TypeInfo for Percent



impl TypeInfo for Permill



impl TypeInfo for Perquintill



impl TypeInfo for BlockLength



impl TypeInfo for BlockWeights



impl TypeInfo for WeightsPerClass



impl TypeInfo for LastRuntimeUpgradeInfo



impl TypeInfo for BlakeTwo256



impl TypeInfo for H160



impl TypeInfo for H256



impl TypeInfo for H512



impl TypeInfo for Keccak256



impl TypeInfo for U256



impl TypeInfo for U512



impl TypeInfo for CheckInherentsResult



impl TypeInfo for InherentData



impl TypeInfo for KeyTypeId



impl TypeInfo for OpaqueKeyOwnershipProof



impl TypeInfo for OpaqueMetadata



impl TypeInfo for RuntimeVersion



impl TypeInfo for Slot



impl TypeInfo for SlotDuration



impl TypeInfo for StorageProof



impl TypeInfo for StorageInfo



impl<A, F, R, D> TypeInfo for FreezeConsideration<A, F, R, D>where F: Mutate<A> + 'static, <F as Inspect<A>>::Balance: TypeInfo + 'static, PhantomData<fn() -> (A, R, D)>: TypeInfo + 'static, A: 'static, R: 'static, D: 'static,



type Identity = FreezeConsideration<A, F, R, D>



impl<A, F, R, D> TypeInfo for HoldConsideration<A, F, R, D>where F: Mutate<A> + 'static, <F as Inspect<A>>::Balance: TypeInfo + 'static, PhantomData<fn() -> (A, R, D)>: TypeInfo + 'static, A: 'static, R: 'static, D: 'static,



type Identity = HoldConsideration<A, F, R, D>



impl<A, Fx, Rx, D> TypeInfo for LoneFreezeConsideration<A, Fx, Rx, D>where PhantomData<fn() -> (A, Fx, Rx, D)>: TypeInfo + 'static, A: 'static, Fx: 'static, Rx: 'static, D: 'static,



type Identity = LoneFreezeConsideration<A, Fx, Rx, D>



impl<A, Fx, Rx, D> TypeInfo for LoneHoldConsideration<A, Fx, Rx, D>where PhantomData<fn() -> (A, Fx, Rx, D)>: TypeInfo + 'static, A: 'static, Fx: 'static, Rx: 'static, D: 'static,



type Identity = LoneHoldConsideration<A, Fx, Rx, D>



impl<AccountId> TypeInfo for RawOrigin<AccountId>where AccountId: TypeInfo + 'static,



type Identity = RawOrigin<AccountId>



impl<BlockNumber> TypeInfo for DispatchTime<BlockNumber>where BlockNumber: TypeInfo + 'static,



type Identity = DispatchTime<BlockNumber>



impl<E, T> TypeInfo for EventRecord<E, T>where E: Parameter + Member + TypeInfo + 'static, Vec<T, Global>: TypeInfo + 'static, T: TypeInfo + 'static,



type Identity = EventRecord<E, T>



impl<H, N> TypeInfo for frame::runtime::apis::Equivocation<H, N>where Equivocation<Public, Prevote<H, N>, Signature>: TypeInfo + 'static, Equivocation<Public, Precommit<H, N>, Signature>: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



impl<H, N> TypeInfo for frame::runtime::apis::EquivocationProof<H, N>where Equivocation<H, N>: TypeInfo + 'static, H: TypeInfo + 'static, N: TypeInfo + 'static,



impl<Header> TypeInfo for GrandpaJustification<Header>where Header: Header + TypeInfo + 'static, Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: TypeInfo + 'static, Vec<Header, Global>: TypeInfo + 'static,



impl<N> TypeInfo for ScheduledChange<N>where N: TypeInfo + 'static,



impl<Nonce, AccountData> TypeInfo for AccountInfo<Nonce, AccountData>where Nonce: TypeInfo + 'static, AccountData: TypeInfo + 'static,



type Identity = AccountInfo<Nonce, AccountData>



impl<T> TypeInfo for Call<T>where T: Config + 'static, PhantomData<(T,)>: TypeInfo + 'static,



type Identity = Call<T>



impl<T> TypeInfo for Error<T>where PhantomData<T>: TypeInfo + 'static, T: 'static,



type Identity = Error<T>



impl<T> TypeInfo for Event<T>where T: Config + 'static, <T as Config>::AccountId: TypeInfo + 'static, <T as Config>::Hash: TypeInfo + 'static, PhantomData<T>: TypeInfo + 'static,



type Identity = Event<T>



impl<T> TypeInfo for CheckMortality<T>where T: Config + Send + Sync + 'static, PhantomData<T>: TypeInfo + 'static,



impl<T> TypeInfo for CheckGenesis<T>where T: Config + Send + Sync + 'static, PhantomData<T>: TypeInfo + 'static,



impl<T> TypeInfo for CheckNonZeroSender<T>where PhantomData<T>: TypeInfo + 'static, T: 'static,



impl<T> TypeInfo for CheckNonce<T>where T: Config + 'static, <T as Config>::Nonce: HasCompact,



impl<T> TypeInfo for CheckSpecVersion<T>where T: Config + Send + Sync + 'static, PhantomData<T>: TypeInfo + 'static,



impl<T> TypeInfo for CheckTxVersion<T>where T: Config + Send + Sync + 'static, PhantomData<T>: TypeInfo + 'static,



impl<T> TypeInfo for CheckWeight<T>where T: Config + Send + Sync + 'static, PhantomData<T>: TypeInfo + 'static,



impl<T> TypeInfo for PhantomData<T>



impl<T> TypeInfo for WrapperKeepOpaque<T>where T: TypeInfo + 'static,



impl<T> TypeInfo for WrapperOpaque<T>where T: TypeInfo + 'static,



impl<T, Hash> TypeInfo for MaybeHashed<T, Hash>where T: TypeInfo + 'static, Hash: TypeInfo + 'static,



type Identity = MaybeHashed<T, Hash>